@@ -3,7 +3,7 @@ package MaxMind::DB::Writer;
 use strict;
 use warnings;
 
-our $VERSION = '0.100002';
+our $VERSION = '0.100003';
 
 1;
 
@@ -19,7 +19,7 @@ MaxMind::DB::Writer - Create MaxMind DB database files
 
 =head1 VERSION
 
-version 0.100002
+version 0.100003
 
 =head1 SYNOPSIS
 
@@ -99,6 +99,12 @@ Mark Fowler <mfowler@maxmind.com>
 
 =back
 
+=head1 CONTRIBUTOR
+
+=for stopwords Florian Ragwitz
+
+Florian Ragwitz <rafl@debian.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by MaxMind, Inc..
